@@ -244,9 +244,9 @@ class EntityManager(object):
     def _include_resources(self, resource: JsonObject, result: JsonObject) -> None:
         for relationship_name, relationship in resource.get("relationships", {}).items():
             relationship_guid = (relationship.get("data") or {}).get("guid")
-            included_resources = result["included"].get(plural(relationship_name), None)
+            included_resources = result["included"].get(plural(relationship_name))
             if relationship_guid is not None and included_resources is not None:
-                included_resource = next((r for r in included_resources if relationship_guid == r.get("guid", None)), None)
+                included_resource = next((r for r in included_resources if relationship_guid == r.get("guid")), None)
                 if included_resource is not None:
                     self._include_resources(included_resource, result)
                     included = resource.setdefault("_included", {})
